@@ -45,6 +45,7 @@ class Structured(MIDITokenizer):
     :param sos_eos: adds Start Of Sequence (SOS) and End Of Sequence (EOS) tokens to the vocabulary.
             (default: False)
     :param mask: will add a MASK token to the vocabulary (default: False)
+    :param sep: will add a SEP token to the vocabulary (default: False)
     :param params: can be a path to the parameter (json encoded) file or a dictionary
     """
 
@@ -57,6 +58,7 @@ class Structured(MIDITokenizer):
         pad: bool = True,
         sos_eos: bool = False,
         mask: bool = False,
+        sep: bool = False,
         params=None,
     ):
         # No additional tokens
@@ -72,6 +74,7 @@ class Structured(MIDITokenizer):
             pad,
             sos_eos,
             mask,
+            sep,
             params=params,
         )
 
@@ -240,7 +243,9 @@ class Structured(MIDITokenizer):
                 "\033[93msos_eos_tokens argument is depreciated and will be removed in a future update, "
                 "_create_vocabulary now uses self._sos_eos attribute set a class init \033[0m"
             )
-        vocab = Vocabulary(pad=self._pad, sos_eos=self._sos_eos, mask=self._mask)
+        vocab = Vocabulary(
+            pad=self._pad, sos_eos=self._sos_eos, mask=self._mask, sep=self._sep
+        )
 
         # PITCH
         vocab.add_event(f"Pitch_{i}" for i in self.pitch_range)
